@@ -18,7 +18,8 @@
 
 /* This file contains functions for controlling local X servers */
 
-#include <config.h>
+#include "config.h"
+
 #include <glib/gi18n.h>
 #include <stdio.h>
 #include <unistd.h>
@@ -27,8 +28,10 @@
 #include <pwd.h>
 #include <grp.h>
 #include <sys/types.h>
+#include <sys/resource.h>
 #include <sys/stat.h>
 #include <sys/wait.h>
+#include <sys/resource.h>
 #include <strings.h>
 #include <signal.h>
 #include <syslog.h>
@@ -47,8 +50,6 @@
 #include "getvt.h"
 #include "gdmconfig.h"
 
-#define SERVER_WAIT_ALARM 10
-
 /* Local prototypes */
 static void gdm_server_spawn (GdmDisplay *d, const char *vtarg);
 static void gdm_server_usr1_handler (gint);
@@ -335,7 +336,7 @@ static gboolean
 busy_ask_user (GdmDisplay *disp)
 {
     /* if we have "open" we can talk to the user */
-    if (g_access (EXPANDED_LIBEXECDIR "/gdmopen", X_OK) == 0) {
+    if (g_access (LIBEXECDIR "/gdmopen", X_OK) == 0) {
 	    char *error = g_strdup_printf
 		    (C_(N_("There already appears to be an X server "
 			   "running on display %s.  Should another "
@@ -558,7 +559,7 @@ do_server_wait (GdmDisplay *d)
 		     * just wait a few seconds and hope things just work,
 		     * fortunately there is no such case yet and probably
 		     * never will, but just for code anality's sake */
-		    gdm_sleep_no_signal (5);
+		    gdm_sleep_no_signal (gdm_get_value_int(GDM_KEY_XSERVER_TIMEOUT));
 	    } else if (d->server_uid != 0) {
 		    int i;
 
@@ -578,7 +579,7 @@ do_server_wait (GdmDisplay *d)
 		    for (i = 0;
 			 d->dsp == NULL &&
 			 d->servstat == SERVER_PENDING &&
-			 i < SERVER_WAIT_ALARM;
+			 i < gdm_get_value_int(GDM_KEY_XSERVER_TIMEOUT);
 			 i++) {
 			    d->dsp = XOpenDisplay (d->name);
 			    if (d->dsp == NULL)
@@ -600,8 +601,9 @@ do_server_wait (GdmDisplay *d)
 			    fd_set rfds;
 			    struct timeval tv;
 
-			    /* Wait up to SERVER_WAIT_ALARM seconds. */
-			    tv.tv_sec = MAX (1, SERVER_WAIT_ALARM - (time (NULL) - t));
+			    /* Wait up to GDM_KEY_XSERVER_TIMEOUT seconds. */
+			    tv.tv_sec = MAX (1, gdm_get_value_int(GDM_KEY_XSERVER_TIMEOUT) 
+			    	- (time (NULL) - t));
 			    tv.tv_usec = 0;
 
 			    FD_ZERO (&rfds);
@@ -613,7 +615,7 @@ do_server_wait (GdmDisplay *d)
 				    VE_IGNORE_EINTR (read (server_signal_pipe[0], buf, 4));
 			    }
 			    if ( ! server_signal_notified &&
-				t + SERVER_WAIT_ALARM < time (NULL)) {
+				t + gdm_get_value_int(GDM_KEY_XSERVER_TIMEOUT) < time (NULL)) {
 				    gdm_debug ("do_server_wait: Server timeout");
 				    d->servstat = SERVER_TIMEOUT;
 				    server_signal_notified = TRUE;
@@ -1393,7 +1395,7 @@ gdm_server_alloc (gint id, const gchar *command)
     
     hostname[1023] = '\0';
     if (gethostname (hostname, 1023) == -1)
-	    strcmp (hostname, "localhost.localdomain");
+	    strcpy (hostname, "localhost.localdomain");
 
     d = g_new0 (GdmDisplay, 1);
 
@@ -1437,6 +1439,7 @@ gdm_server_alloc (gint id, const gchar *command)
     d->retry_count = 0;
     d->sleep_before_run = 0;
     d->login = NULL;
+    d->preset_user = NULL;
 
     d->timed_login_ok = FALSE;
 
